@@ -10,7 +10,7 @@
 #' The default number for `k` is 2.
 #'
 #' @templateVar id clust.agnes
-#' @template section_dictionary_learner
+#' @template learner
 #' @template example
 #'
 #' @export
@@ -20,36 +20,24 @@ LearnerClustAgnes = R6Class("LearnerClustAgnes",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      ps = ParamSet$new(
-        params = list(
-          ParamFct$new("metric",
-            default = "euclidean",
-            levels = c("euclidean", "manhattan"), tags = "train"
-          ),
-          ParamLgl$new("stand", default = FALSE, tags = "train"),
-          ParamFct$new("method",
-            default = "average",
-            levels = c(
-              "average", "single", "complete", "ward",
-              "weighted", "flexible", "gaverage"
-            ), tags = "train"
-          ),
-          ParamInt$new("trace.lev", lower = 0L, default = 0L, tags = "train"),
-          ParamInt$new("k", lower = 1L, default = 2L, tags = "predict"),
-          ParamUty$new(
-            id = "par.method", tags = "train",
-            custom_check = function(x) {
-              if (test_numeric(x) || test_list(x)) {
-                if (length(x) %in% c(1L, 3L, 4L)) {
-                  return(TRUE)
-                }
-                stop("`par.method` needs be of length 1, 3, or 4")
-              } else {
-                stop("`par.method` needs to be a numeric vector")
+      ps = ps(
+        metric = p_fct(default = "euclidean", levels = c("euclidean", "manhattan"), tags = "train"),
+        stand = p_lgl(default = FALSE, tags = "train"),
+        method = p_fct(default = "average", levels = c("average", "single", "complete", "ward", "weighted", "flexible", "gaverage"), tags = "train"),
+        trace.lev = p_int(lower = 0L, default = 0L, tags = "train"),
+        k = p_int(lower = 1L, default = 2L, tags = "predict"),
+        par.method = p_uty(tags = "train", custom_check = function(x) {
+            if (test_numeric(x) || test_list(x)) {
+              if (length(x) %in% c(1L, 3L, 4L)) {
+                return(TRUE)
               }
-            })
-        )
+              stop("`par.method` needs be of length 1, 3, or 4")
+            } else {
+              stop("`par.method` needs to be a numeric vector")
+            }
+          })
       )
+
       # param deps
       ps$add_dep("par.method", "method", CondAnyOf$new(c("flexible", "gaverage")))
 
@@ -61,7 +49,8 @@ LearnerClustAgnes = R6Class("LearnerClustAgnes",
         predict_types = "partition",
         param_set = ps,
         properties = c("hierarchical", "exclusive", "complete"),
-        packages = "cluster"
+        packages = "cluster",
+        label = "Agglomerative Hierarchical Clustering"
       )
     }
   ),
